"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const fs = require("fs");
const noFileOrDirectoryFound = 'ENOENT';
exports.initiateStreams = async (files, streamGetterFunc) => {
    const fileStreams = files.map(async (file) => {
        const stream = await streamGetterFunc(file.url);
        const path = file.path;
        return { stream, path };
    });
    return await Promise.all(fileStreams);
};
exports.pipeFiles = async (commanderFeedback, resolvedFileStreams) => {
    const filePromises = resolvedFileStreams.map(async (stream) => {
        const status = commanderFeedback(stream);
        try {
            const response = await pipeFile(stream);
            status.succeed();
            return response;
        }
        catch (e) {
            if (e.code === noFileOrDirectoryFound) {
                status.info(`Ignoring ${stream.path}, because cant find folders for location`);
                return {};
            }
            else {
                status.fail(e.message);
                throw e;
            }
        }
    });
    return await Promise.all(filePromises);
};
const pipeFile = ({ stream, path }) => {
    return new Promise((resolve, reject) => {
        try {
            const file = fs.createWriteStream(path);
            stream.data.pipe(file);
            file.on('finish', () => {
                resolve(true);
            }).on('error', (err) => {
                reject(err);
            });
        }
        catch (e) {
            reject(e);
        }
    });
};
