"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const axios_1 = require("axios");
const urls_1 = require("./urls");
const lodash_1 = require("lodash");
let token = '';
exports.setToken = (passedInToken) => {
    token = passedInToken;
};
const request = async (extractUrlMethod, options) => {
    const axiosDefaultOptions = {
        method: 'GET',
        url: extractUrlMethod(),
        headers: {
            Authorization: `token ${token}`,
        },
    };
    const mergedOptions = lodash_1.merge(axiosDefaultOptions, options);
    return await axios_1.default(mergedOptions);
};
exports.getContent = async (repo, service, branch) => {
    try {
        return await request(() => urls_1.getContentUrl(repo, service, branch));
    }
    catch (e) {
        throw e;
    }
};
exports.getGitTree = async (repo, sha, branch) => {
    try {
        return await request(() => urls_1.getGitTreeUrl(repo, sha, branch));
    }
    catch (e) {
        throw e;
    }
};
exports.getFile = async (url) => {
    try {
        const requestParameters = {
            responseType: 'stream',
            headers: {
                Accept: 'application/vnd.github.v3.raw'
            }
        };
        return await request(() => urls_1.getUrl(url), requestParameters);
    }
    catch (e) {
        throw e;
    }
};
exports.validateToken = async (repo) => {
    try {
        return await request(() => urls_1.getRepoUrl(repo));
    }
    catch (e) {
        throw e;
    }
};
