"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const api_1 = require("./api");
const service_error_1 = require("../../errors/service-error");
const parseError = (e, message) => {
    if (e.response && e.response.status && e.response.config) {
        const status = e.response.status;
        const compiledMessage = `${message} ${e.config.url}`;
        const error = new service_error_1.default(e, compiledMessage, status);
        return error;
    }
    else {
        return e;
    }
};
exports.initGithubService = (token) => {
    api_1.setToken(token);
};
exports.getContentFromRepo = async (repo, service, branch) => {
    try {
        return await api_1.getContent(repo, service, branch);
    }
    catch (e) {
        throw parseError(e, `External service to gitContents failed on`);
    }
};
exports.getGitTreeFromRepo = async (repo, sha, branch) => {
    try {
        return await api_1.getGitTree(repo, sha, branch);
    }
    catch (e) {
        throw parseError(e, `External service call to gitTree failed on`);
    }
};
exports.getFileFromRepo = async (url) => {
    try {
        return await api_1.getFile(url);
    }
    catch (e) {
        throw parseError(e, `External service call to get file as stream failed on`);
    }
};
exports.validateTokenOnRepo = async (repo) => {
    try {
        return await api_1.validateToken(repo);
    }
    catch (e) {
        throw parseError(e, `Token invalid`);
    }
};
